# CppHeaderParser package
# Author: Jashua Cloutier (contact via sourceforge username:senexcanis)
import sys
if sys.version_info[0] == 2:
    from CppHeaderParser import *
else:
    from CppHeaderParser3 import *

#__all__ = ['CppHeaderParser']
